# dialoghelper


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This file will become your README and also the index of your
documentation.

## Developer Guide

If you are new to using `nbdev` here are some useful pointers to get you
started.

### Install dialoghelper in Development mode

``` sh
# make sure dialoghelper package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to dialoghelper
$ nbdev_prepare
```

## Usage

### Installation

Install latest from the GitHub
[repository](https://github.com/AnswerDotAI/dialoghelper):

``` sh
$ pip install git+https://github.com/AnswerDotAI/dialoghelper.git
```

or from [conda](https://anaconda.org/AnswerDotAI/dialoghelper)

``` sh
$ conda install -c AnswerDotAI dialoghelper
```

or from [pypi](https://pypi.org/project/dialoghelper/)

``` sh
$ pip install dialoghelper
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/AnswerDotAI/dialoghelper)’s
[pages](https://AnswerDotAI.github.io/dialoghelper/). Additionally you
can find package manager specific guidelines on
[conda](https://anaconda.org/AnswerDotAI/dialoghelper) and
[pypi](https://pypi.org/project/dialoghelper/) respectively.

## How to use

Fill me in please! Don’t forget code examples:

``` python
1+1
```

    2
